@@ -156,8 +156,8 @@ class EjabberdBaseAPI(ABC):
 
     @abstractmethod
     def add_rosteritem(self,
-                       localuser, localserver,
-                       user, server,
+                       localuser, localhost,
+                       user, host,
                        nick, group, subs):
         """
         Add an item to a user's roster (self,supports ODBC):
@@ -206,11 +206,17 @@ class EjabberdBaseAPI(ABC):
     # TODO def convert_to_yaml(self, in, out):
     # Convert the input file from Erlang to YAML format
 
-    # TODO def create_room(self, name, service, host):
-    # Create a MUC room name@service in host
-
-    # TODO def create_room_with_opts(self, name, service, host, options):
-    # Create a MUC room name@service in host with given options
+    @abstractmethod
+    def create_room_with_opts(self, name, service, host, options):
+        """
+        Create a MUC room name@service in host with given options
+        :param name:
+        :param service:
+        :param host:
+        :param options:
+        :return:
+        """
+        raise NotImplementedError("subclass must implement this method")
 
     # TODO def create_rooms_file(self, file):
     # Create the rooms indicated in file
@@ -343,11 +349,25 @@ class EjabberdBaseAPI(ABC):
         """
         raise NotImplementedError("subclass must implement this method")
 
-    # TODO get_subscribers(self, name, service):
-    # List subscribers of a MUC conference
+    @abstractmethod
+    def get_subscribers(self, name, service):
+        """
+        List subscribers of a MUC conference
+        :param name:
+        :param service:
+        :return:
+        """
+        raise NotImplementedError("subclass must implement this method")
+
+    def get_user_rooms(self, user, host):
+        """
+        Get the list of rooms where this user is occupant
+        :param user:
+        :param host:
+        :return:
+        """
+        raise NotImplementedError("subclass must implement this method")
 
-    # TODO get_user_rooms(self, user, host):
-    # Get the list of rooms where this user is occupant
     @abstractmethod
     def get_vcard(self, user, host, name):
         """
@@ -760,11 +780,25 @@ class EjabberdBaseAPI(ABC):
         """
         raise NotImplementedError("subclass must implement this method")
 
-    # TODO def subscribe_room(self, user, nick, room, nodes):
-    # Subscribe to a MUC conference
+    def subscribe_room(self, user, nick, room, nodes):
+        """
+        Subscribe to a MUC conference
+        :param user:
+        :param nick:
+        :param room:
+        :param nodes:
+        :return:
+        """
+        raise NotImplementedError("subclass must implement this method")
 
-    # TODO def unsubscribe_room(self, user, room):
-    # Unsubscribe from a MUC conference
+    def unsubscribe_room(self, user, room):
+        """
+        Unsubscribe from a MUC conference
+        :param user:
+        :param room:
+        :return:
+        """
+        raise NotImplementedError("subclass must implement this method")
 
     @abstractmethod
     def update(self, module):
