@@ -172,6 +172,7 @@ class EjabberdAPIClient(EjabberdBaseAPI):
         self._report_method_call(api.method, args)
 
         # perform call
+        print("auth args: %s, args: %s" % (self.auth, args))
         try:
             if not api.authenticate:
                 response = method(args)
@@ -255,16 +256,16 @@ class EjabberdAPIClient(EjabberdBaseAPI):
         return self._call_api(methods.CheckPasswordHash, user=user, host=host, password=password)
 
     def add_rosteritem(self,
-                       localuser, localserver,
-                       user, server,
-                       nick, group, subs):
+                       localuser, localhost,
+                       user, host,
+                       nick="", group="", subs="to"):
         """
         Add an item to a user's roster (self,supports ODBC):
         """
         return self._call_api(methods.AddRosterItem, localuser=localuser,
-                              localserver=localserver,
+                              localhost=localhost,
                               user=user,
-                              server=server,
+                              host=host,
                               nick=nick,
                               group=group,
                               subs=subs)
@@ -329,11 +330,18 @@ class EjabberdAPIClient(EjabberdBaseAPI):
     # TODO def convert_to_yaml(self, in, out):
     # Convert the input file from Erlang to YAML format
 
-    # TODO def create_room(self, name, service, host):
-    # Create a MUC room name@service in host
+    def create_room_with_opts(self, name, service, host, options):
+        """
+        Create a MUC room name@service in host with given options
+        :param name:
+        :param service:
+        :param host:
+        :param options: Room options. Example: options = [{"name": "members_only","value": "False"},
+                                                        {"name": "moderated","value": "False"}]
+        :return:
 
-    # TODO def create_room_with_opts(self, name, service, host, options):
-    # Create a MUC room name@service in host with given options
+        """
+        return self._call_api(methods.CreateRoomWithOpts, name=name, service=service, host=host, options=options)
 
     # TODO def create_rooms_file(self, file):
     # Create the rooms indicated in file
@@ -485,11 +493,26 @@ class EjabberdAPIClient(EjabberdBaseAPI):
 
         return self._call_api(methods.GetRoster, user=user, server=server)
 
-    # TODO get_subscribers(self, name, service):
-    # List subscribers of a MUC conference
+    def get_subscribers(self, name, service):
+        """
+         List subscribers of a MUC conference
 
-    # TODO get_user_rooms(self, user, host):
-    # Get the list of rooms where this user is occupant
+        :param name: Room name
+        :type name: str
+        :param service: MUC service
+        :type service: str
+        :return:
+        """
+        return self._call_api(methods.GetSubscribers, name=name, service=service)
+
+    def get_user_rooms(self, user, host):
+        """
+        Get the list of rooms where this user is occupant
+        :param user:
+        :param host:
+        :return:
+        """
+        return self._call_api(methods.GetUserRooms, user=user, host=host)
 
     def get_vcard(self, user, host, name):
         """
@@ -936,15 +959,31 @@ class EjabberdAPIClient(EjabberdBaseAPI):
         return self._call_api(methods.StopKindly,
                               delay=delay, announcement=announcement)
 
-    # TODO def subscribe_room(self, user, nick, room, nodes):
-    # Subscribe to a MUC conference
+    def subscribe_room(self, user, nick, room, nodes=None):
+        """
+        Subscribe to a MUC conference
+        :param user:
+        :param nick:
+        :param room:
+        :param nodes:
+        :return:
+        """
+        return self._call_api(methods.SubscribeRoom, user=user, nick=nick, room=room, nodes=nodes)
 
-    # TODO def unsubscribe_room(self, user, room):
-    # Unsubscribe from a MUC conference
+    def unsubscribe_room(self, user, room):
+        """
+        Unsubscribe from a MUC conference
+        :param user:
+        :param room:
+        :return:
+        """
+        return self._call_api(methods.UnSubscribeRoom, user=user, room=room)
 
     def update(self, module):
         """
         Update the given module, or use the keyword: all
+
+        :param module:
         """
         return self._call_api(methods.Update, module=module)
 
